MOOGPy
======

This is a redistribution of the `MOOG stellar spectral
synthesis software <https://github.com/jsobeck/MOOG-SCAT_basic_git>`_
as well as my own python wrapper code.


Authors
-------

- **David Nidever** (Montana State University)
  
Installation
------------

To install the latest version::

    pip install moogpy

    
Documentation
-------------

.. image:: https://readthedocs.org/projects/moogpy/badge/?version=latest
        :target: http://moogpy.readthedocs.io/

See `the documentation <http://moogpy.readthedocs.io>`_ for information on how
to install and use MOOGPy.

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dnidever/moogpy/blob/main/LICENSE
